<!DOCTYPE TS><TS>
<context>
    <name>AddRecording</name>
    <message>
        <source>Schedule a:</source>
        <translation>Plane eine(n):</translation>
    </message>
    <message>
        <source>&amp;Recording</source>
        <translation>&amp;Aufnahme</translation>
    </message>
    <message>
        <source>&amp;Playout</source>
        <translation>A&amp;bspielen</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Herunterladen</translation>
    </message>
    <message>
        <source>&amp;Upload</source>
        <translation>H&amp;ochladen</translation>
    </message>
    <message>
        <source>&amp;Macro Cart</source>
        <translation>&amp;Makro Cart</translation>
    </message>
    <message>
        <source>&amp;Switch Event</source>
        <translation>&amp;Switch Event</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>CatchListView</name>
    <message>
        <source>Edit Cue Markers</source>
        <translation>Cue Marker editieren</translation>
    </message>
</context>
<context>
    <name>DeckMon</name>
    <message>
        <source>MON</source>
        <translation>MON</translation>
    </message>
    <message>
        <source>ABORT</source>
        <translation>ABBRECHEN</translation>
    </message>
    <message>
        <source>OFFLINE</source>
        <translation>OFFLINE</translation>
    </message>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>IDLE</source>
        <translation>LEERLAUF</translation>
    </message>
    <message>
        <source>READY</source>
        <translation>FERTIG</translation>
    </message>
    <message>
        <source>WAITING</source>
        <translation>WARTEN</translation>
    </message>
    <message>
        <source>RECORDING</source>
        <translation>AUFNAHME</translation>
    </message>
    <message>
        <source>PLAYING</source>
        <translation>ABSPIELEN</translation>
    </message>
    <message>
        <source>[multiple events]</source>
        <translation>[mehrere events]</translation>
    </message>
    <message>
        <source>[unknown cut]</source>
        <translation>[unbekannter cut]</translation>
    </message>
    <message>
        <source>[no description]</source>
        <translation>[keine beschreibung]</translation>
    </message>
</context>
<context>
    <name>EditCartEvent</name>
    <message>
        <source>Edit Cart Event</source>
        <translation>Cart Event editieren</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Event Aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ort:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Startzeit:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Cart Number:</source>
        <translation>Cart-Nummer:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>Au&amp;swählen</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktive Tage</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Nur Einmal</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Speichern als
Neu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Doppeltes Event</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Ein Event mit diesen Parametern existiert bereits!</translation>
    </message>
    <message>
        <source>Invalid Cart</source>
        <translation>Ungültiger Cart</translation>
    </message>
    <message>
        <source>That cart doesn&apos;t exist!</source>
        <translation>Dieser Cart existiert nicht!</translation>
    </message>
</context>
<context>
    <name>EditDownload</name>
    <message>
        <source>Edit Download</source>
        <translation>Download editieren</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Event aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ort:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Startzeit:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Ziel:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>Au&amp;swählen</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Level:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalisieren</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktive Tage</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Nur Einmal</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Speichern als
Neu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Doppeltes Event</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Ein Event mit diesen Parametern existiert bereits!</translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>Ungültige URL</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>Die URL ist ungültig!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>Nicht unterstütztes URL-Protokoll!</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation>Event-Abstand:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>Tage</translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation>FehlenderBenutzername</translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation>Sie müssen einen Benutzernamen angeben!</translation>
    </message>
    <message>
        <source>Update Library Metadata</source>
        <translation>Bibliotheksmetadaten updaten</translation>
    </message>
</context>
<context>
    <name>EditPlayout</name>
    <message>
        <source>Edit Playout</source>
        <translation>Auspielung editieren</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Event aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ort:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Startzeit:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Ziel:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>Au&amp;swählen</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktive Tage</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Nur Einmal</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Speichern als
Neu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Doppeltes Event</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Ein Event mit diesen Parametern existiert bereits!</translation>
    </message>
</context>
<context>
    <name>EditRecording</name>
    <message>
        <source>Edit Recording</source>
        <translation>Aufnahme editieren</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Event aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ort:</translation>
    </message>
    <message>
        <source>Start Parameters</source>
        <translation>Startparameter</translation>
    </message>
    <message>
        <source>Use Hard Time</source>
        <translation>Feste Zeit verwenden</translation>
    </message>
    <message>
        <source>Record Start Time:</source>
        <translation>Aufnahmestartzeit:</translation>
    </message>
    <message>
        <source>Use GPI</source>
        <translation>GPI verwenden</translation>
    </message>
    <message>
        <source>Window Start Time:</source>
        <translation>Fensterstartzeit:</translation>
    </message>
    <message>
        <source>GPI Matrix:</source>
        <translation>GPI Matrix:</translation>
    </message>
    <message>
        <source>GPI Line:</source>
        <translation>GPI-Line:</translation>
    </message>
    <message>
        <source>Start Delay:</source>
        <translation>Startverzögerung:</translation>
    </message>
    <message>
        <source>Allow Multiple Recordings within this Window</source>
        <translation>Mehrfache Aufnahmen in diesem Fenster erlauben</translation>
    </message>
    <message>
        <source>End Parameters</source>
        <translation>Endparameter</translation>
    </message>
    <message>
        <source>Use Length</source>
        <translation>Verwende Länge</translation>
    </message>
    <message>
        <source>Record Length:</source>
        <translation>Aufnahmelänge:</translation>
    </message>
    <message>
        <source>Record End Time:</source>
        <translation>Aufnahmeendzeit:</translation>
    </message>
    <message>
        <source>Window End Time:</source>
        <translation>Fensterendzeit:</translation>
    </message>
    <message>
        <source>Max Record Length:</source>
        <translation>Maximale Aufnahmelänge:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Quelle:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Ziel:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>Au&amp;swählen</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Level:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalisieren</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktive Tage</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Start Date Offset:</source>
        <translation>Startdatums-Abstand:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>End Date Offset:</source>
        <translation>Enddatums-Abstand:</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Nur Einmal</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Speichern als
Neu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>CUT</translation>
    </message>
    <message>
        <source>Missing Cut</source>
        <translation>Cut fehlt</translation>
    </message>
    <message>
        <source>You must assign a record cut!</source>
        <translation>Sie müssen einen Aufnahme-Cut auswählen!</translation>
    </message>
    <message>
        <source>Record Parameter Error</source>
        <translation>Aufnahmeparameter-Fehler</translation>
    </message>
    <message>
        <source>The start GPI window cannot end before it begins!</source>
        <translation>Das Start-GPI-Fenster kann nicht enden, bevor es anfängt!</translation>
    </message>
    <message>
        <source>The recording cannot end before it begins!</source>
        <translation>Die Aufnahme kann nicht enden, bevor sie anfängt!</translation>
    </message>
    <message>
        <source>The end GPI window cannot end before it begins!</source>
        <translation>Das End-GPI-Fenster kann nicht enden, bevor es anfängt!</translation>
    </message>
    <message>
        <source>The start GPI matrix doesn&apos;t exist!</source>
        <translation>Die Start-GPI-Matrix existiert nicht!</translation>
    </message>
    <message>
        <source>The start GPI line doesn&apos;t exist!</source>
        <translation>Die Start-GPI-LINE existiert nicht!</translation>
    </message>
    <message>
        <source>The end GPI matrix doesn&apos;t exist!</source>
        <translation>Die End-GPI-Matrix existiert nicht!</translation>
    </message>
    <message>
        <source>The end GPI line doesn&apos;t exist!</source>
        <translation>Die End-GPI-Line existiert nicht!</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Doppeltes Event</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Ein Event mit diesen Parametern existiert bereits!</translation>
    </message>
</context>
<context>
    <name>EditSwitchEvent</name>
    <message>
        <source>Edit Switcher Event</source>
        <translation>Switcher-Event editieren</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Event aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ort:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Startzeit:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Switch Matrix:</source>
        <translation>Switch-Matrix:</translation>
    </message>
    <message>
        <source>Switch Input:</source>
        <translation>Switch-Input:</translation>
    </message>
    <message>
        <source>Switch Output:</source>
        <translation>Switch-Output:</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktive Tage</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Nur Einmal</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Speichern als
Neu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>--OFF--</source>
        <translation>--AUS--</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Doppeltes Event</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Ein Event mit diesen Parametern existiert bereits!</translation>
    </message>
</context>
<context>
    <name>EditUpload</name>
    <message>
        <source>Edit Upload</source>
        <translation>Hochladen editieren</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Event aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ort:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Startzeit:</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[keine]</translation>
    </message>
    <message>
        <source>RSS Feed:</source>
        <translation>RSS Feed:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Quelle:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>Au&amp;swählen</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Export Format:</source>
        <translation>Exportformat:</translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation>S&amp;etzen</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalisieren</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Level:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktive Tage</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Nur Einmal</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Speichern als
Neu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Unsupported Format</source>
        <translation>Nicht unterstützes Format</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on this host!</source>
        <translation>Das derzeit ausgewählte Exportformat wird auf diesem Host nicht unterstützt!</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>CUT</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Doppeltes Event</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Ein Event mit diesen Parametern existiert bereits!</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on host </source>
        <translation>Das derzeit ausgewählte Exportformat wird auf diesem Host nicht unterstützt</translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>Ungültige URL</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>Die URL ist ungültig!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>Nicht unterstütztes URL-Protokoll!</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation>Event-Abstand:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>Tage</translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation>FehlenderBenutzername</translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation>Sie müssen einen Benutzernamen angeben!</translation>
    </message>
    <message>
        <source>Export Library Metadata</source>
        <translation>Bibliotheksmetadaten exportieren</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation>RDLibrary Reports</translation>
    </message>
    <message>
        <source>Event Report</source>
        <translation>Event Report</translation>
    </message>
    <message>
        <source>Upload/Download Report</source>
        <translation>Upload/Download-Report</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>&amp;Generieren</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chließen</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCatch - Host:</source>
        <translation type="obsolete">RDCatch - Host:</translation>
    </message>
    <message>
        <source>rdcatch : </source>
        <translation>rdcatch : </translation>
    </message>
    <message>
        <source>Show Only Active Events</source>
        <translation>Nur aktive Events zeigen</translation>
    </message>
    <message>
        <source>Show Only Today&apos;s Events</source>
        <translation>Nur heutige Events zeigen</translation>
    </message>
    <message>
        <source>Show DayOfWeek:</source>
        <translation>Wochentage anzeigen:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Wochentage</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>LOCATION</source>
        <translation>ORT</translation>
    </message>
    <message>
        <source>START</source>
        <translation>START</translation>
    </message>
    <message>
        <source>END</source>
        <translation>ENDE</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation>QUELLE</translation>
    </message>
    <message>
        <source>DESTINATION</source>
        <translation>ZIEL</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation>HERKUNFT</translation>
    </message>
    <message>
        <source>ONE SHOT</source>
        <translation>EINMAL</translation>
    </message>
    <message>
        <source>TRIM THRESHOLD</source>
        <translation>TRIM THRESHOLD</translation>
    </message>
    <message>
        <source>STARTDATE OFFSET</source>
        <translation>Startdatums-Abstand</translation>
    </message>
    <message>
        <source>ENDDATE OFFSET</source>
        <translation>Enddatums-Abstand</translation>
    </message>
    <message>
        <source>FORMAT</source>
        <translation>FORMAT</translation>
    </message>
    <message>
        <source>CHANNELS</source>
        <translation>KANÄLE</translation>
    </message>
    <message>
        <source>SAMPLE RATE</source>
        <translation>SAMPLE RATE</translation>
    </message>
    <message>
        <source>BIT RATE</source>
        <translation>BITRATE</translation>
    </message>
    <message>
        <source>STATION</source>
        <translation>STATION</translation>
    </message>
    <message>
        <source>DECK</source>
        <translation>DECK</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation>CUT</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CART</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYP</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation>STATUS</translation>
    </message>
    <message>
        <source>EXIT CODE</source>
        <translation>EXIT CODE</translation>
    </message>
    <message>
        <source>STATE</source>
        <translation>ZUSTAND</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Scrollen</translation>
    </message>
    <message>
        <source>Reports</source>
        <translation>Reporte</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chliessen</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Event aktiv</translation>
    </message>
    <message>
        <source>You cannot edit an active event!</source>
        <translation>Sie können kein aktives event editieren!</translation>
    </message>
    <message>
        <source>Are you sure you want to delete event</source>
        <translation>Sind sie sicher, daß sie das Event löschen wollen</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Event löschen</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>kann nicht verbinden</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>Verbindung zur Core AudioEngine fehlgeschlagen</translation>
    </message>
    <message>
        <source>Control connection timed out to host</source>
        <translation>Kontrollverbindungs-TimeOut zum Host</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>So</translation>
    </message>
    <message>
        <source>Mo</source>
        <translation>Mo</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Di</translation>
    </message>
    <message>
        <source>We</source>
        <translation>Mi</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Do</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>fr</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>Sa</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>Hard</source>
        <translation>Hard</translation>
    </message>
    <message>
        <source>Gpi</source>
        <translation>Gpi</translation>
    </message>
    <message>
        <source>Len</source>
        <translation>Länge</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>MPEG Layer 1</source>
        <translation>MPEG Layer 1</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG Layer 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG Layer 3</translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation>FLAC</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>OggVorbis</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Cart</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[keine]</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="obsolete">Kurze Länge</translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="obsolete">Niedriges Level</translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="obsolete">Hohes Level</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Herunterladen</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="obsolete">Hochladen</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="obsolete">Aufnehmen</translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="obsolete">Abspielen</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="obsolete">Warten</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="obsolete">Serverfehler</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Interner Fehler</translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="obsolete">Unterbrochen</translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="obsolete">Gerät beschäftigt</translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="obsolete">Kein solcher Cart/Cut</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
    <message>
        <source>Show Event Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Types</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
